@@ -46,7 +46,7 @@ describe 'glance::backend::multistore::swift' do
         is_expected.to contain_glance_api_config('swift/swift_store_create_container_on_put').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('swift/swift_store_endpoint_type').with_value('internalURL')
         is_expected.to contain_glance_api_config('swift/swift_store_region').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_glance_api_config('swift/swift_store_config_file').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_glance_api_config('swift/swift_store_config_file').with_value('/etc/glance/glance-swift.conf')
         is_expected.to contain_glance_api_config('swift/default_swift_reference').with_value('ref1')
         is_expected.to contain_glance_api_config('swift/swift_buffer_on_upload').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('swift/swift_upload_buffer_dir').with_value('<SERVICE DEFAULT>')
@@ -75,7 +75,7 @@ describe 'glance::backend::multistore::swift' do
           :swift_store_create_container_on_put => true,
           :swift_store_endpoint_type           => 'publicURL',
           :swift_store_region                  => 'RegionTwo',
-          :swift_store_config_file             => '/etc/glance/glance-swift.conf',
+          :swift_store_config_file             => '/etc/glance/glance-swift2.conf',
           :default_swift_reference             => 'swift_creds',
           :swift_buffer_on_upload              => true,
           :swift_upload_buffer_dir             => '/var/glance/swift',
@@ -90,7 +90,7 @@ describe 'glance::backend::multistore::swift' do
         is_expected.to contain_glance_api_config('swift/swift_store_large_object_chunk_size').with_value('50')
         is_expected.to contain_glance_api_config('swift/swift_store_endpoint_type').with_value('publicURL')
         is_expected.to contain_glance_api_config('swift/swift_store_region').with_value('RegionTwo')
-        is_expected.to contain_glance_api_config('swift/swift_store_config_file').with_value('/etc/glance/glance-swift.conf')
+        is_expected.to contain_glance_api_config('swift/swift_store_config_file').with_value('/etc/glance/glance-swift2.conf')
         is_expected.to contain_glance_api_config('swift/default_swift_reference').with_value('swift_creds')
         is_expected.to contain_glance_api_config('swift/swift_buffer_on_upload').with_value(true)
         is_expected.to contain_glance_api_config('swift/swift_upload_buffer_dir').with_value('/var/glance/swift')
